@@ -68,7 +68,7 @@ class AutoUpdateFileBasedCache(FileBasedCache):
         super(AutoUpdateFileBasedCache, self).__init__(*args, **kwargs)
         import warnings
         warnings.warn(
-            "django-tools AutoUpdateFileBasedCache is deprecated, use new SoomthCache!",
+            "django-tools AutoUpdateFileBasedCache is deprecated, use new SmoothCacheBackends!",
             category=DeprecationWarning
         )
 
